U-Net
=====


.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.3522306.svg
        :target: https://doi.org/10.5281/zenodo.3522306
        :alt: DOI

.. image:: https://img.shields.io/badge/License-MIT-yellow.svg
        :target: https://opensource.org/licenses/MIT
        :alt: License

.. image:: https://img.shields.io/pypi/v/unet.svg
        :target: https://pypi.python.org/pypi/unet


PyTorch implementation of 2D and 3D U-Net.

The U-Net architecture was first described in
`Ronneberger et al. 2015, U-Net: Convolutional Networks for Biomedical Image
Segmentation <https://arxiv.org/abs/1505.04597>`_.
The 3D version was described in
`Çiçek et al. 2016, 3D U-Net: Learning Dense Volumetric Segmentation from
Sparse Annotation <https://arxiv.org/abs/1606.06650>`_.


Installation
------------

::

   pip install unet


Credits
-------

If you used this code for your research, please cite this repository using the
information available on its
`Zenodo entry <https://doi.org/10.5281/zenodo.3522306>`_.
